@@ -9,7 +9,9 @@ use Carp;
 
 our @EXPORT = qw(check_vcs vcs_tag make_vcs_tag);
 
-$VERSION = '2.06_01';
+$VERSION = '2.06_04';
+
+=encoding utf8
 
 =head1 NAME
 
@@ -258,7 +260,7 @@ L<Module::Release>
 
 This source is in Github:
 
-	git://github.com/briandfoy/module-release.git
+	https://github.com/briandfoy/module-release
 
 =head1 AUTHOR
 
@@ -266,7 +268,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2007-2011, brian d foy, All Rights Reserved.
+Copyright (c) 2007-2013, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
